state
------------------------

.. automodule:: flax.nnx
.. currentmodule:: flax.nnx


.. autoclass:: State
  :members:

.. autoclass:: FlatState
  :members:

.. autofunction:: filter_state
.. autofunction:: from_flat_state
.. autofunction:: map_state
.. autofunction:: merge_state
.. autofunction:: replace_by_pure_dict
.. autofunction:: restore_int_paths
.. autofunction:: to_flat_state
.. autofunction:: to_pure_dict
.. autofunction:: split_state
